@@ -50,6 +50,13 @@ fn main() {
         println!("{}", val);
     }
 
+    if let Some(_) = matches.subcommand_matches("barecode.isbn") {
+        use fake::faker::barecode::fr_fr;
+        
+        let val: String = fr_fr::Isbn13().fake();
+        println!("{}", val);
+    }
+    
     if let Some(mail) = matches.subcommand_matches("internet.mail") {
         use fake::faker::internet::raw::FreeEmail;
 
@@ -145,4 +152,21 @@ fn main() {
         let val: String = Time(EN).fake();
         println!("{}", val);
     }
+    
+    if let Some(s) = matches.subcommand_matches("filesystem.semver") {
+        use fake::faker::filesystem::raw::{Semver, SemverStable, SemverUnstable};
+        let val: String;
+        if let Some(_) = s.value_of("stable") {
+            val = SemverStable(EN).fake();
+            println!("{}", val);
+            return;
+        }
+        if let Some(_) = s.value_of("unstable") {
+            val = SemverUnstable(EN).fake();
+            println!("{}", val);
+            return;
+        }
+        val = Semver(EN).fake();
+        println!("{}", val);
+    }
 }
